@@ -141,7 +141,7 @@ class Renderer(base.Renderer):
         """Return the url to the attachments view, if available.
         We expect this call only occurs when self.project is not None
         """
-        cfilter = {'portal_type': ('File', 'Image')}
+        cfilter = {'portal_type': ('File', 'Image', 'Story')}
         brains = self.project.getFolderContents(cfilter)
         if brains and len(brains) > 0:
             return self.project_url + '/project_content?type=other'
